import pytest

from py4jdbc.dbapi2 import Connection
from py4jdbc.gateway_process import GatewayProcess


@pytest.fixture(scope='session')
def gateway(request):
    gateway = GatewayProcess()
    gateway.__enter__()
    def finalizer():
        gateway.shutdown()
    request.addfinalizer(finalizer)
    return gateway


@pytest.fixture(scope='session')
def derby(request):
    # Start a gateway.
    gateway = GatewayProcess()
    gateway.__enter__()

    # Start a derby in-memory connection.
    url = "jdbc:derby:memory:testdb;create=true"
    conn = Connection(url, gateway=gateway)
    conn.__enter__()

    def finalizer():
        conn.__exit__()
        gateway.shutdown()
    request.addfinalizer(finalizer)

    return conn






import pytest

from py4jdbc.dbapi2 import connect, Connection
from py4jdbc.resultset import ResultSet
from py4jdbc.exceptions.dbapi2 import Error


def test_get_tables(derby):
    cur = derby.cursor()
    rs = cur.execute("select * from SYS.SYSTABLES")
    sql_names = [row.TABLENAME for row in rs]
    jdbc_names = [row.TABLE_NAME for row in derby.get_tables()]
    assert set(sql_names) == set(jdbc_names)


def test_get_columns(derby):
    cur = derby.cursor()
    rs = cur.execute("select * from SYS.SYSCOLUMNS")
    sql_names = [row.COLUMNNAME for row in rs]
    jdbc_names = [row.COLUMN_NAME for row in derby.get_columns()]
    assert  set(jdbc_names).issubset(set(sql_names))








import pytest

from py4jdbc.dbapi2 import connect, Connection
from py4jdbc.resultset import ResultSet
from py4jdbc.exceptions.dbapi2 import Error


def test_connect(gateway):
    url = "jdbc:derby:memory:testdb;create=true"
    conn = connect(url, gateway=gateway)
    cur = conn.cursor()
    rs = cur.execute("select * from SYS.SYSTABLES")
    assert isinstance(rs, ResultSet)

def test_execute(derby):
    cur = derby.cursor()
    rs = cur.execute("select * from SYS.SYSTABLES")
    assert isinstance(rs, ResultSet)


def test_fetchone(derby):
    cur = derby.cursor()
    rs = cur.execute("select * from SYS.SYSTABLES")
    assert isinstance(rs.fetchone(), rs.Row)


def test_fetchmany(derby):
    '''Assert all rows of result set have the correct class.
    '''
    cur = derby.cursor()
    rs = cur.execute("select * from SYS.SYSTABLES")
    assert all({isinstance(row, rs.Row) for row in rs.fetchmany(5)})


def test_fetchall(derby):
    '''Assert all rows of result set have the correct class.
    '''
    cur = derby.cursor()
    rs = cur.execute("select * from SYS.SYSTABLES")
    assert all({isinstance(row, rs.Row) for row in rs.fetchall()})


def test_Cursor__iter__(derby):
    cur = derby.cursor()
    rs = cur.execute("select * from SYS.SYSTABLES")
    assert all({isinstance(row, rs.Row) for row in rs})


def test_Cursor__iter__(derby):
    cur = derby.cursor()
    rs = cur.execute("select * from SYS.SYSTABLES")
    # Exhaust all rows.
    list(rs)
    assert rs.fetchone() == None


def test_close_and_execute(derby):
    cur = derby.cursor()
    cur.close()
    with pytest.raises(Error):
        cur.execute("select * from SYS.SYSTABLES")


def test_close_and_fetchone(derby):
    cur = derby.cursor()
    cur.execute("select * from SYS.SYSTABLES")
    cur.close()
    with pytest.raises(Error):
        cur.fetchone()


def test_close_twice(derby):
    cur = derby.cursor()
    cur.close()
    with pytest.raises(Error):
        cur.close()





import pytest

from py4jdbc.dbapi2 import Connection
from py4jdbc.exceptions import dbapi2
from py4jdbc.exceptions import sqlstate


def test_jdbc_bogus_driver(gateway):
    url = "jdbc:darby:memory:testdb;create=true"
    conn = Connection(url, gateway=gateway)
    with pytest.raises(sqlstate.ConnectionError), conn:
        cur = derby.cursor()
        rs = cur.execute("select * from SYS.SYSTABLES")


def test_jdbc_bogus_table(derby):
    cur = derby.cursor()
    with pytest.raises(sqlstate.SyntaxOrAccessRuleViolationError):
        rs = cur.execute("select * from BOGUS_TABLE")




#!/usr/bin/env python
# -*- coding: utf-8 -*-


try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


with open('README.rst') as readme_file:
    readme = readme_file.read()

requirements = ["py4j"]
test_requirements = ["pytest", "coverage"]

exec(compile(open("py4jdbc/version.py").read(), "py4jdbc/version.py", 'exec'))
VERSION = __version__  # noqa


setup(
    name='py4jdbc',
    version=VERSION,
    description="py4j JDBC wrapper",
    long_description=readme,
    author="Thom Neale",
    author_email='tneale@massmutual.com',
    url='https://github.com/massmutual/py4jdbc',
    packages=['py4jdbc', 'py4jdbc.exceptions'],
    install_requires=requirements,
    license="BSD",
    zip_safe=False,
    keywords=['jdbc', 'dbapi', 'py4j'],
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    test_suite='tests',
    tests_require=test_requirements,
    scripts=[
        'scripts/sbtassembly',
        'scripts/dockerbuild',
        'scripts/travistests',
    ]
)
